==> risk-center-api-0.5.7-20190814.033503-8-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/CompeteMaterialParam.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

@ApiModel("情报系统素材中心")
public class CompeteMaterialParam extends ReqPageQuery {

    private static final long serialVersionUID = -5624163221143850803L;
    @ApiModelProperty("竞品")
    private String competeName;

    @ApiModelProperty("媒体")
    private List<String> mediaList;

    @ApiModelProperty("出券顺序")
    private Integer couponOrder;

    @ApiModelProperty("地域")
    private String city;

    @ApiModelProperty("行业")
    private List<Long> industryId;

    @ApiModelProperty("资源")
    private List<Long> resourceId;

    @ApiModelProperty("竞品id列表")
    private List<Long> competeIdList;

    public String getCompeteName() {
        return competeName;
    }

    public void setCompeteName(String competeName) {
        this.competeName = competeName;
    }

    public List<String> getMediaList() {
        return mediaList;
    }

    public void setMediaList(List<String> mediaList) {
        this.mediaList = mediaList;
    }

    public Integer getCouponOrder() {
        return couponOrder;
    }

    public void setCouponOrder(Integer couponOrder) {
        this.couponOrder = couponOrder;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public List<Long> getIndustryId() {
        return industryId;
    }

    public void setIndustryId(List<Long> industryId) {
        this.industryId = industryId;
    }

    public List<Long> getResourceId() {
        return resourceId;
    }

    public void setResourceId(List<Long> resourceId) {
        this.resourceId = resourceId;
    }

    public List<Long> getCompeteIdList() {
        return competeIdList;
    }

    public void setCompeteIdList(List<Long> competeIdList) {
        this.competeIdList = competeIdList;
    }
}

==> risk-center-api-0.5.7-20190814.034532-10-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/CompeteMaterialParam.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

@ApiModel("情报系统素材中心")
public class CompeteMaterialParam extends ReqPageQuery {

    private static final long serialVersionUID = -5624163221143850803L;
    @ApiModelProperty("竞品")
    private String competeName;

    @ApiModelProperty("媒体")
    private List<String> mediaList;

    @ApiModelProperty("出券顺序")
    private Integer couponOrder;

    @ApiModelProperty("地域")
    private String city;

    @ApiModelProperty("行业")
    private List<Long> industryIdList;

    @ApiModelProperty("资源")
    private List<Long> resourceIdList;

    @ApiModelProperty("竞品id列表")
    private List<Long> competeIdList;

    public String getCompeteName() {
        return competeName;
    }

    public void setCompeteName(String competeName) {
        this.competeName = competeName;
    }

    public List<String> getMediaList() {
        return mediaList;
    }

    public void setMediaList(List<String> mediaList) {
        this.mediaList = mediaList;
    }

    public Integer getCouponOrder() {
        return couponOrder;
    }

    public void setCouponOrder(Integer couponOrder) {
        this.couponOrder = couponOrder;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public List<Long> getIndustryIdList() {
        return industryIdList;
    }

    public void setIndustryIdList(List<Long> industryIdList) {
        this.industryIdList = industryIdList;
    }

    public List<Long> getResourceIdList() {
        return resourceIdList;
    }

    public void setResourceIdList(List<Long> resourceIdList) {
        this.resourceIdList = resourceIdList;
    }

    public List<Long> getCompeteIdList() {
        return competeIdList;
    }

    public void setCompeteIdList(List<Long> competeIdList) {
        this.competeIdList = competeIdList;
    }
}
